@@ -1,7 +1,6 @@
 #!/usr/pkg/bin/python3.10
-from __future__ import division, print_function, absolute_import
 
-from numpy.testing import assert_almost_equal, assert_allclose
+from numpy.testing import assert_allclose, assert_almost_equal
 
 import pywt
 
